==> tine20-allinone_2020.08.8.tar.bz2: Tasks/js/Tasks-lang-nb-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Tasks **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Tasks'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2018-11-28 11:10+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: Norwegian Bokmål (http://www.transifex.com/tine20/tine20/language/nb/)\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nLanguage: nb\nPlural-Forms: nplurals=2; plural=(n != 1);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "GENDER_Task, GENDER_Tasks"
: [
  ""
 ,""

]
, "Task, Tasks"
: [
  "Oppgave"
 ,"Oppgaver"

]
, "Percent"
: "Prosent"

, "Completed"
: "Fullført"

, "Due"
: "Utløper"

, "Class"
: ""

, "Description"
: "Beskrivelse"

, "Geo"
: ""

, "Location"
: ""

, "Organizer"
: "Planlegger"

, "Priority"
: "Prioritet"

, "Status, Status"
: [
  ""
 ,""

]
, "Lead"
: ""

, "Telephone"
: ""

, "Email"
: ""

, "Add New Task"
: ""

, "You have to supply a due date, because an alarm ist set!"
: ""

, "Summary"
: "Oppsumering"

, "Due date"
: "Utløps dato"

, "Add Responsible ..."
: "Legg til Ansvarlige ..."

, "Notes"
: "Notater"

, "Enter description..."
: "Tast inn beskrivelse..."

, "Percentage"
: "Prosent"

, "Tasks"
: "Oppgaver"

, "to do list, to do lists"
: [
  "å gjør liste"
 ,"å gjøre lister"

]
, "to do lists"
: "å gjøre lister"

, "Quick Search"
: ""

, "Due Date"
: "Utløps Dato"

, "Responsible"
: "Ansvarlig"

, "Last Modified Time"
: ""

, "Last Modified By"
: ""

, "Creation Time"
: "Opprettelses Tid"

, "Created By"
: ""

, "New Task"
: ""

, "Do you really want to delete the selected task?, Do you really want to delete the selected tasks?"
: [
  "Vil du virkelig slette valgt oppgave?"
 ,"Vil du virkelig slette valgte oppgaver?"

]
, "Attachments"
: ""

, "Tags"
: "Merker"

, "Lead name"
: ""

, "Add a task..."
: "Legg til en oppgave..."

, "All my tasks"
: ""

, "Default Favorite"
: ""

, "The default favorite which is loaded on Tasks startup"
: ""

, "Default Task List"
: ""

, "The default task list to create new tasks in."
: ""

, "Tasks status available"
: ""

, "Possible tasks status. Please note that additional attendee status might impact other Tasks systems on export or syncronisation."
: ""

, "No response"
: ""

, "Cancelled"
: ""

, "In process"
: ""

, "Task priorities available"
: ""

, "Possible task priorities. Please note that additional priorities might impact other Tasks systems on export or syncronisation."
: ""

, "low"
: ""

, "normal"
: ""

, "high"
: ""

, "urgent"
: ""

, "manage shared task lists"
: "behandle delte oppgaver lister"

, "Create new shared tasks lists"
: "Opprett ny delt oppgaver liste"

, "manage shared tasks favorites"
: ""

, "Create or update shared tasks favorites"
: ""

, "%s's personal tasks"
: "%s's personlige oppgaver"

, "Notification for Task %1$s"
: ""

, "All tasks of my taskslists"
: ""

, "My open tasks"
: ""

, "My open tasks this week"
: ""

, "All tasks for me"
: ""

, "All tasks that I am responsible for"
: ""

, "Last modified by me"
: ""

, "All tasks that I have last modified"
: ""

, "Tasks without responsible"
: ""

, "GENDER_Task"
: ""

, "Task"
: "Oppgave"

, "Status"
: ""

, "to do list"
: "å gjør liste"

, "Do you really want to delete the selected task?"
: "Vil du virkelig slette valgt oppgave?"

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;

==> tine20-allinone_2021.12.1.tar.bz2: Tasks/js/Tasks-lang-nb-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Tasks **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Tasks'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2018-11-28 11:10+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: Norwegian Bokmål (http://www.transifex.com/tine20/tine20/language/nb/)\nLanguage: nb\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=2; plural=(n != 1);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "Add New Task"
: ""

, "You have to supply a due date, because an alarm ist set!"
: ""

, "Summary"
: "Oppsumering"

, "Due date"
: "Utløps dato"

, "Priority"
: "Prioritet"

, "Organizer"
: "Planlegger"

, "Add Responsible ..."
: "Legg til Ansvarlige ..."

, "Notes"
: "Notater"

, "Enter description..."
: "Tast inn beskrivelse..."

, "Percentage"
: "Prosent"

, "Status, Status"
: [
  ""
 ,""

]
, "Completed"
: "Fullført"

, "Do you really want to delete the selected task?, Do you really want to delete the selected tasks?"
: [
  "Vil du virkelig slette valgt oppgave?"
 ,"Vil du virkelig slette valgte oppgaver?"

]
, "Attachments"
: ""

, "Tags"
: "Merker"

, "Lead name"
: ""

, "Add a task..."
: "Legg til en oppgave..."

, "Due Date"
: "Utløps Dato"

, "Percent"
: "Prosent"

, "Responsible"
: "Ansvarlig"

, "Task, Tasks"
: [
  "Oppgave"
 ,"Oppgaver"

]
, "Tasks"
: "Oppgaver"

, "to do list, to do lists"
: [
  "å gjør liste"
 ,"å gjøre lister"

]
, "to do lists"
: "å gjøre lister"

, "Quick Search"
: ""

, "Last Modified Time"
: ""

, "Last Modified By"
: ""

, "Creation Time"
: "Opprettelses Tid"

, "Created By"
: ""

, "New Task"
: ""

, "All my tasks"
: ""

, "Default Favorite"
: ""

, "The default favorite which is loaded on Tasks startup"
: ""

, "Default Task List"
: ""

, "The default task list to create new tasks in."
: ""

, "Enable Standard Alarm"
: ""

, "New task get a standard alarm as defined below"
: ""

, "Standard Alarm Time"
: ""

, "Minutes before the task ends"
: ""

, "Tasks status available"
: ""

, "Possible tasks status. Please note that additional attendee status might impact other Tasks systems on export or syncronisation."
: ""

, "No response"
: ""

, "Cancelled"
: ""

, "In process"
: ""

, "Task priorities available"
: ""

, "Possible task priorities. Please note that additional priorities might impact other Tasks systems on export or syncronisation."
: ""

, "low"
: ""

, "normal"
: ""

, "high"
: ""

, "urgent"
: ""

, "%s's personal tasks"
: "%s's personlige oppgaver"

, "GENDER_Task"
: ""

, "Due"
: "Utløper"

, "Class"
: ""

, "Description"
: "Beskrivelse"

, "Geo"
: ""

, "Location"
: ""

, "Lead"
: ""

, "Telephone"
: ""

, "Email"
: ""

, "Notification for Task %1$s"
: ""

, "All tasks of my taskslists"
: ""

, "My open tasks"
: ""

, "My open tasks this week"
: ""

, "All tasks for me"
: ""

, "All tasks that I am responsible for"
: ""

, "Last modified by me"
: ""

, "All tasks that I have last modified"
: ""

, "Tasks without responsible"
: ""

, "manage shared task lists"
: "behandle delte oppgaver lister"

, "Create new shared tasks lists"
: "Opprett ny delt oppgaver liste"

, "manage shared tasks favorites"
: ""

, "Create or update shared tasks favorites"
: ""

, "Status"
: ""

, "Do you really want to delete the selected task?"
: "Vil du virkelig slette valgt oppgave?"

, "Task"
: "Oppgave"

, "to do list"
: "å gjør liste"

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;
